@@ -66,6 +66,7 @@ describe 'trove::api' do
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_user').with_value('admin')
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
         is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
+        is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('DEFAULT/control_exchange').with_value('trove')
         is_expected.to contain_trove_config('DEFAULT/os_region_name').with_value('RegionOne')
         is_expected.to contain_trove_config('DEFAULT/nova_compute_service_type').with_value('compute')
@@ -79,17 +80,25 @@ describe 'trove::api' do
         is_expected.to contain_trove_config('DEFAULT/http_delete_rate').with_value('200')
         is_expected.to contain_trove_config('DEFAULT/http_mgmt_post_rate').with_value('200')
         is_expected.to contain_trove_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('DEFAULT/taskmanager_queue').with_value('taskmanager')
+        is_expected.to contain_trove_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_config('DEFAULT/control_exchange').with_value('trove')
+        is_expected.to contain_trove_config('DEFAULT/remote_nova_client').with_ensure('absent')
+        is_expected.to contain_trove_config('DEFAULT/remote_cinder_client').with_ensure('absent')
+        is_expected.to contain_trove_config('DEFAULT/remote_neutron_client').with_ensure('absent')
         is_expected.to contain_trove_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('ssl/cert_file').with_ensure('absent')
         is_expected.to contain_trove_config('ssl/key_file').with_ensure('absent')
         is_expected.to contain_trove_config('ssl/ca_file').with_ensure('absent')
+        is_expected.to contain_oslo__messaging__rabbit('trove_config').with(
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
+        )
       end
 
       context 'with SSL enabled on API' do
@@ -128,6 +137,22 @@ describe 'trove::api' do
         end
       end
 
+      context 'with single tenant mode enabled' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             single_tenant_mode    => 'true'}
+           class { '::trove::keystone::authtoken':
+             password => 'a_big_secret',
+           }"
+        end
+        it 'single tenant client values are set' do
+          is_expected.to contain_trove_config('DEFAULT/remote_nova_client').with_value('trove.common.single_tenant_remote.nova_client_trove_admin')
+          is_expected.to contain_trove_config('DEFAULT/remote_cinder_client').with_value('trove.common.single_tenant_remote.cinder_client_trove_admin')
+          is_expected.to contain_trove_config('DEFAULT/remote_neutron_client').with_value('trove.common.single_tenant_remote.neutron_client_trove_admin')
+        end
+      end
+
       context 'when using a single RabbitMQ server' do
         let :pre_condition do
           "class { 'trove':
@@ -178,6 +203,49 @@ describe 'trove::api' do
         end
       end
 
+      context 'when using Neutron' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass    => 'verysecrete',
+             use_neutron              => true,
+             default_neutron_networks => 'trove_service',
+           }
+           class { '::trove::keystone::authtoken':
+             password => 'a_big_secret',
+           }"
+        end
+
+        it 'configures trove to use the Neutron network driver' do
+          is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_value('trove_service')
+          is_expected.to contain_trove_config('DEFAULT/network_driver').with_value('trove.network.neutron.NeutronDriver')
+        end
+
+        it 'configures trove to use any network label' do
+          is_expected.to contain_trove_config('DEFAULT/network_label_regex').with_value('.*')
+        end
+      end
+
+      context 'when using Nova Network' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             use_neutron           => false
+           }
+           class { '::trove::keystone::authtoken':
+             password => 'a_big_secret',
+           }"
+        end
+
+        it 'configures trove to use the Nova Network network driver' do
+          is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_ensure('absent')
+          is_expected.to contain_trove_config('DEFAULT/network_driver').with_value('trove.network.nova.NovaNetwork')
+        end
+
+        it 'configures trove to use the "private" network label' do
+          is_expected.to contain_trove_config('DEFAULT/network_label_regex').with_value('^private$')
+        end
+      end
+
     end
 
     context 'with SSL enabled with kombu' do
@@ -195,11 +263,13 @@ describe 'trove::api' do
       end
 
       it do
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+        is_expected.to contain_oslo__messaging__rabbit('trove_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+          :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+          :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+          :kombu_ssl_version  => 'TLSv1',
+        )
       end
     end
 
@@ -214,11 +284,13 @@ describe 'trove::api' do
       end
 
       it do
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
@@ -226,26 +298,30 @@ describe 'trove::api' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => false}
+           rabbit_use_ssl        => false}
          class { '::trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
 
       it do
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_config').with(
+          :rabbit_use_ssl     => false,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     context 'with transport_url entries' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
-           default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+           nova_proxy_admin_pass      => 'verysecrete',
+           default_transport_url      => 'rabbit://rabbit_user:password@localhost:5673',
+           rpc_response_timeout       => '120',
+           control_exchange           => 'openstack',
            notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673' }
          class { '::trove::keystone::authtoken':
            password => 'a_big_secret',
@@ -254,6 +330,8 @@ describe 'trove::api' do
 
       it do
         is_expected.to contain_trove_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+        is_expected.to contain_trove_config('DEFAULT/rpc_response_timeout').with_value('120')
+        is_expected.to contain_trove_config('DEFAULT/control_exchange').with_value('openstack')
         is_expected.to contain_trove_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
       end
     end
@@ -269,7 +347,6 @@ describe 'trove::api' do
       end
 
       it do
-        is_expected.to contain_trove_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_trove_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
