@@ -27,24 +27,22 @@ describe 'trove::guestagent' do
       end
 
       it 'configures trove-guestagent with default parameters' do
-        is_expected.to contain_trove_guestagent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('DEFAULT/use_syslog').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('DEFAULT/syslog_log_facility').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('DEFAULT/log_file').with_value('/var/log/trove/trove-guestagent.log')
-        is_expected.to contain_trove_guestagent_config('DEFAULT/log_dir').with_value('/var/log/trove')
         is_expected.to contain_trove_guestagent_config('DEFAULT/os_region_name').with_value('RegionOne')
         is_expected.to contain_trove_guestagent_config('DEFAULT/control_exchange').with_value('trove')
         is_expected.to contain_trove_guestagent_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/control_exchange').with_value('trove')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_guestagent_config').with(
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
+        )
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('DEFAULT/swift_url').with_value('<SERVICE DEFAULT>')
@@ -55,6 +53,16 @@ describe 'trove::guestagent' do
         is_expected.to contain_trove_guestagent_config('DEFAULT/backup_aes_cbc_key').with_value('<SERVICE DEFAULT>')
       end
 
+      it 'configures trove-guestagent with default logging parameters' do
+        is_expected.to contain_oslo__log('trove_guestagent_config').with(
+          :use_syslog          => '<SERVICE DEFAULT>',
+          :syslog_log_facility => '<SERVICE DEFAULT>',
+          :log_dir             => '/var/log/trove',
+          :log_file            => '/var/log/trove/trove-guestagent.log',
+          :debug               => '<SERVICE DEFAULT>',
+        )
+      end
+
       context 'when using a single RabbitMQ server' do
         let :pre_condition do
           "class { 'trove':
@@ -99,10 +107,14 @@ describe 'trove::guestagent' do
         let :pre_condition do
           "class { 'trove':
              nova_proxy_admin_pass => 'verysecrete',
-             default_transport_url => 'rabbit://user:pass@host:1234/virt',}"
+             default_transport_url => 'rabbit://user:pass@host:1234/virt',
+             rpc_response_timeout  => '120',
+             control_exchange      => 'openstack',}"
         end
         it 'configures trove-guestagent with DEFAULT/transport_url' do
           is_expected.to contain_trove_guestagent_config('DEFAULT/transport_url').with_value('rabbit://user:pass@host:1234/virt')
+          is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_response_timeout').with_value('120')
+          is_expected.to contain_trove_guestagent_config('DEFAULT/control_exchange').with_value('openstack')
         end
       end
 
@@ -115,12 +127,12 @@ describe 'trove::guestagent' do
       end
 
       let :params do
-        { :auth_url => "http://10.0.0.1:5000/v2.0",
-          :swift_url => "http://10.0.0.1:8080/v1/AUTH_",
+        { :auth_url           => "http://10.0.0.1:5000/v2.0",
+          :swift_url          => "http://10.0.0.1:8080/v1/AUTH_",
           :swift_service_type => 'object-store',
-          :rabbit_host => '10.1.0.1',
-          :rabbit_port => '5673',
-          :rabbit_use_ssl => 'true'
+          :rabbit_host        => '10.1.0.1',
+          :rabbit_port        => '5673',
+          :rabbit_use_ssl     => 'true'
         }
       end
       it 'configures trove-guestagent with custom parameters' do
@@ -129,7 +141,9 @@ describe 'trove::guestagent' do
         is_expected.to contain_trove_guestagent_config('DEFAULT/swift_service_type').with_value('object-store')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_host').with_value('10.1.0.1')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
+        is_expected.to contain_oslo__messaging__rabbit('trove_guestagent_config').with(
+          :rabbit_use_ssl => 'true',
+        )
       end
     end
 
@@ -145,11 +159,13 @@ describe 'trove::guestagent' do
       end
 
       it do
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+        is_expected.to contain_oslo__messaging__rabbit('trove_guestagent_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+          :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+          :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+          :kombu_ssl_version  => 'TLSv1',
+        )
       end
     end
 
@@ -157,15 +173,17 @@ describe 'trove::guestagent' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => true}"
+           rabbit_use_ssl        => true}"
       end
 
       it do
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_guestagent_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
@@ -173,28 +191,34 @@ describe 'trove::guestagent' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => false}"
+           rabbit_use_ssl        => false}"
       end
 
       it do
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_guestagent_config').with(
+          :rabbit_use_ssl     => false,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     context 'with transport_url entries' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
-           default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+           nova_proxy_admin_pass      => 'verysecrete',
+           default_transport_url      => 'rabbit://rabbit_user:password@localhost:5673',
+           rpc_response_timeout       => '60',
+           control_exchange           => 'exchange',
            notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673' }"
       end
 
       it do
         is_expected.to contain_trove_guestagent_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_response_timeout').with_value('60')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/control_exchange').with_value('exchange')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
       end
     end
@@ -207,7 +231,6 @@ describe 'trove::guestagent' do
       end
 
       it do
-        is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
